<template>
    <el-dialog
        :visible.sync="superiorDepartmentVisible"
        append-to-body
        :close-on-click-modal="false"
        width="75%"
    >
        <div class="app-container">
            <div class="filter-container">
                <div class="basic_search">
                    <span>区域：</span>
                    <el-select v-model="listQuery.filter.province" clearable filterable @change="changeArea('province')">
                        <el-option
                            v-for="item in provinceList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.city" prop="city" clearable filterable @change="changeArea('city')">
                        <el-option
                            v-for="item in cityList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.district" clearable filterable @change="changeArea('district')">
                        <el-option
                            v-for="item in districtList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.street"clearable filterable @change="changeArea('street')" >
                        <el-option
                            v-for="item in streetList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div style="display: block;padding-top: 10px;padding-bottom: 10px">
                    <div class="basic_search">
                        <span>安全监管分类：</span>
                        <el-select filterable clearable v-model="listQuery.filter.safetysupervision">
                            <el-option
                                v-for="item in safetySuperVisionList"
                                :key="item.id"
                                :label="item.text"
                                :value="item.text"
                            ></el-option>
                        </el-select>
                    </div>
                    <div class="basic_search" style="margin-left:10px">
                        <span>企业名称：</span>
                        <el-input v-model="listQuery.filter.enterprisename" style="width:200px">
                        </el-input>
                    </div>
                    <el-button  type="primary" icon="el-icon-search" @click="queryHandle" />
                </div>
            </div>
            <div class="table_content">
                <el-table
                    v-loading="listLoading"
                    :key="tableKey"
                    :data="superiorDepartmentListData"
                    border
                    fit
                    highlight-current-row
                    style="width: 100%;"
                >
                    <el-table-column label="序号" type="index" align="center" width="60"/>
                    <el-table-column label="级别" prop="enteenterprisesizerprisename" align="center">
                        <template slot-scope="scope">
                            <span>{{ scope.row.enterprisename }}</span>
                        </template>
                    </el-table-column>
                    <el-table-column label="机构代码" prop="province" align="center">
                    </el-table-column>
                    <el-table-column label="机构名字" prop="enterprisename" align="center">
                        <template slot-scope="scope">
                            <span>{{ scope.row.enterprisesize }}</span>
                        </template>
                    </el-table-column>
                    <el-table-column label="操作" align="center" width="180" class-name="small-padding fixed-width">
                        <template slot-scope="scope">
                            <!--            <el-button type="text" @click="showEditHandle(scope.row)">编辑</el-button>-->
                            <el-button type="text" @click="updatePublicSecurityDepartment('修改',scope.row)">选择</el-button>
                        </template>
                    </el-table-column>
                </el-table>
                <br>
                <el-pagination
                    v-show="recordTotal>0"
                    :current-page="currentPage"
                    :page-sizes="[10, 20, 30, 50]"
                    :page-size="pageSize"
                    :total="recordTotal"
                    layout="total, sizes, prev, pager, next, jumper"
                    background
                    style="float:right;"
                    @size-change="handleSizeChange"
                    @current-change="handleCurrentChange"
                />
            </div>
        </div>
    </el-dialog>
</template>

<script>
import {computePageCount} from "../../../../utils";
import {  getSuperiorDepartmentList } from '@/api/enterprise'
import {getCityListData, getProvinceListData} from "../../../../api/area";
export default {
    name: "publicSecurityDepartment",
    data(){
        return{
            tableKey:0,
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            searchContent:'',
            listQuery:{
                filter: {enterprisename:"",safetysupervision:"",province:"",city:"",district:"",street:""},
                pageIndex: 1,
                pageSize:10
            },
            provinceList:[],
            cityList:[],
            districtList:[],
            streetList:[],
            safetySuperVisionList:[],
            superiorDepartmentVisible:false,
            superiorDepartmentListData:[],
        }
    },
    created(){
        this.getSuperiorDepartmentListData()
        this.getProvince()
    },
    methods:{
        showEnterPrise(value){
            this.superiorDepartmentVisible = true
            this.safetySuperVisionList = value
            this.getSuperiorDepartmentListData()
        },
        async getProvince(){
            let res = await getProvinceListData()
            if(res.data.code === "200"){
                this.provinceList = res.data.result.provinceList
            }
        },//获取省

        async changeArea(value){
            if(value === 'province'){
                this.listQuery.filter.city = ''
                this.listQuery.filter.district = ''
                this.listQuery.filter.street = ''
                this.areaListQuery = {
                    type: 2,
                    parenttype: 1,
                    parentname: this.listQuery.filter.province,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.cityList = res.data.result
                }
            }else if(value === 'city'){
                this.listQuery.filter.district = ''
                this.listQuery.filter.street = ''
                this.areaListQuery = {
                    type: 3,
                    parenttype: 2,
                    parentname: this.listQuery.filter.city,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.districtList = res.data.result
                }
            }else if(value === 'district'){
                this.listQuery.filter.street = ''
                this.areaListQuery = {
                    type: 4,
                    parenttype: 3,
                    parentname: this.listQuery.filter.district,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.streetList = res.data.result
                }
            }
        },//市、镇、街道、委员会

        async getSuperiorDepartmentListData(){
            let res = await getSuperiorDepartmentList(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.superiorDepartmentListData = res.data.result.records
            }
        },
        refreshHandle(){

        },
        queryHandle(){
            this.getSuperiorDepartmentListData()
        },
        updatePublicSecurityDepartment(title,value){
            this.$emit('getinfo',value.enterprisename)
            this.superiorDepartmentVisible = false
        },
        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getSuperiorDepartmentListData()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getSuperiorDepartmentListData()
        },
    }
}
</script>

<style scoped>
.basic_search{
    display:inline-block;
}
</style>
